pilas.fondos

Package pilas :: Module fondos |
[hide private]
[frames] | no frames]

# Module fondos

source code

Classes | [hide private]
| Fondo
| Volley Muestra una escena que tiene un fondo de pantalla de paisaje.
| Nubes Muestra un fondo celeste con nubes.
| Pasto Muestra una escena que tiene un fondo de pantalla de paisaje.
| Selva Muestra una escena que tiene un fondo de pantalla de paisaje.
| Tarde Representa una escena de fondo casi naranja.
| Espacio Es un espacio con estrellas.
| Noche Muestra una escena que tiene un fondo de pantalla de paisaje.
| Color Pinta todo el fondo de un color uniforme.
| Desplazamiento Representa un fondo formado por varias capas (o actores).
| Plano

Variables | [hide private]
| __package__ = ``'``pilas``'``